--variables
v = vessel.get_focusinterface()

--create screen annotation
note = oapi.create_annotation()
note:set_pos (0,0.1,0.9,0.95)
note:set_colour ({r=1,g=0.6,b=0.2})



--functions
function delayout(text)
note:set_text (text)
proc.wait_sysdt(5)
end

function RadToDeg(r)
d = (360 * r)/ (2 * PI)
return d
end

function intro()
delayout('Welcome to the interactive LEO tutorial.')
delayout('This tutorial will guide you into low Earth orbit.')
delayout ('Press CTRL-P to pause and think at any time.')
delayout ('This tutorial is intended for people who are relatively new to Orbiter.')
delayout ('You should already know the basic controls, and how to change MFD modes.')
delayout ('The 2D panel view will be best to use if you\'re unfamiliar with Orbiter. (F2 to change)')
end


function mfd()
delayout ('So let\'s get started! First, Open Orbit MFD in the right panel.')
delayout ('Press PRJ until you see SHP in the top right. This shows our ship\'s current orbit.')
delayout ('As you can see, our orbit is shown as a line to the centre of the planet.')
delayout ('When we\'re in orbit, the mfd will show a full circle around the Earth.')
delayout ('Also, press DST so the MFD displays altitudes.')
delayout ('We\'ll use Orbit MFD later, so keep it open.')
delayout ('Now, in the left panel, Open Surface MFD.')
delayout ('We\'ll use this MFD to make sure we\'re flying at the right heading, and right pitch.')
delayout ('If the HUD isn\'t already in surface mode, press HUD on the MFD.')
delayout ('We\'re now ready to go!')
end

function takeoff()
delayout ('When you\'re ready, engage full throttle.')

while v:get_thrustergrouplevel(THGROUP.MAIN) < 0.9 do
proc.skip()
end

note:set_text ('When you reach 100 m/s (check top left of your HUD), pitch up.')

while v:get_airspeed() < 100 do
proc.skip()
end

note:set_text ('Okay, now gradually pitch up.')

while v:get_altitude() < 100 do
proc.skip()
end

delayout ('Nice takeoff! Now retract landing gear by pressing G.')

end


function yawpitch()
delayout ('Time to get into the right heading.')
delayout ('Bank to the right (numpad 6) and pitch up slightly (numpad 2)')
delayout ('This will rotate your craft into a new heading.')
delayout ('Watch your heading indicator (top of HUD / surface MFD) move around.')
delayout ('Our target heading is 090.')
delayout ('Begin to level out when you get nearer to 090 (numpad 4)')
note:set_text ('Try to fly at a heading of 090.')

while RadToDeg(v:get_yaw()) < 85 or RadToDeg(v:get_yaw()) > 95 do
proc.skip()
end

delayout ('Good work. Try to stay on this heading.')

note:set_text ('Now pitch up (stick back or numpad 2) to 50 degrees.')

while RadToDeg(v:get_pitch()) < 45 or RadToDeg(v:get_pitch()) > 55 do
proc.skip()
end

note:set_text ('Continue to gain altitude with this pitch and heading.')

end

function rcspitch()

while v:get_altitude() < 25e3 do
if RadToDeg(v:get_pitch()) < 45 or RadToDeg(v:get_pitch()) > 55 then
note:set_text ('Remember to keep your pitch at about 50.')
elseif RadToDeg(v:get_yaw()) < 85 or RadToDeg(v:get_yaw()) > 95 then
note:set_text ('Remember to keep your heading around 090.')
else
note:set_text ('Continue to gain altitude with this pitch and heading.')
end
proc.skip()
end


note:set_text('The atmosphere is getting thin. Switch to RCS ROT (dial on the right or / on numpad)')

while v:get_rcsmode() ~= RCSMODE.ROT do
proc.skip()
end

delayout('Good, you are now controlling the craft with rocket motors instead of control surfaces.')

note:set_text('Now pitch down to 20 degrees.')
while RadToDeg(v:get_pitch()) < 15 or RadToDeg(v:get_pitch()) > 25 do
proc.skip()
end

delayout('Okay, now look at ApA on Orbit MFD.')
delayout('You should aim to get this to about 250 km.')
delayout('Also look at Vel. This should be about 7500 m/s for a stable orbit.')

end


function GetApA()
el, op = v:get_elementsex()
ApA = op['ApD'] - 6.37101e6
return ApA
end

function GetVel()
vecvel = v:get_relativevel(v:get_gravityref())
len = vec.length(vecvel)
return len
end

function gainaltvel()
note:set_text('Continue burning engines. Target ApA - ~250km. Target Vel - ~7500')

while GetVel() < 7500 or GetApA() < 250e3 do 
if RadToDeg(v:get_pitch()) < 15 or RadToDeg(v:get_pitch()) > 25 then
note:set_text ('Remember to keep your pitch at about 20.')
elseif v:get_rcsmode() ~= RCSMODE.ROT then
note:set_text ('You need to stay in rotation RCS mode!')
elseif RadToDeg(v:get_yaw()) < 85 or RadToDeg(v:get_yaw()) > 95 then
note:set_text ('Remember to keep your heading around 090.')
else
note:set_text ('Continue burning engines. Target ApA - ~250km. Target Vel - ~7500')
end
proc.skip() 
end

note:set_text('You may now cutoff the engines, or keep burning if you want a higher orbit.')

while v:get_thrustergrouplevel(THGROUP.MAIN) > 0 do proc.skip() end

end


function GetApT()
el, op = v:get_elementsex()
ApT = op['ApT']
return ApT
end


function GetEcc()
el, op = v:get_elementsex()
ecc = el['e']
return ecc
end


function raisep()
delayout('You are nearly in a stable orbit. Only more thing to do - Raise the perigee.')
delayout('Look at Orbit MFD. Some of your Orbit is still below the Earth\'s surface!')
delayout('To fix this, we will make a final burn at our apogee (highest point), to raise our perigee (lowest point)')
delayout('Look at the ApT value on the Orbit MFD. This is the time (s) until we reach the apogee.')
note:set_text('Accelerate time (press t to speed up, r to slow down) until ApT reaches about 150 seconds.')

while GetApT() > 150 do proc.skip() end

delayout('To raise our perigee, we need to be pointing prograde (in the direction of travel)')
delayout('Luckily, Orbiter has an autopilot to hold the ship in the right direction while we burn.')
delayout('Press the prograde autopilot button (at the bottom of the screen)')
note:set_text('Once you\'ve activated the autopilot, wait until ApT = ~20. Then you can start the burn.')

while GetApT() > 21 do proc.skip() end
note:set_text('Engage main engines!')

while v:get_thrustergrouplevel(THGROUP.MAIN) < 0.9 do proc.skip() end

delayout('Watch the Ecc value in Orbit MFD. The closer to 0, the more circular your orbit.')
note:set_text('Try to get Ecc to less than 0.02.')
while GetEcc() > 0.02 do proc.skip() end

note:set_text('Cut off your engines, or keep going to perfect your orbit. Don\'t overshoot!')

while v:get_thrustergrouplevel(THGROUP.MAIN) > 0 do proc.skip() end

delayout('Congratulations, you\'ve made it into orbit!')

end



--begin tutorial
intro()
mfd()
takeoff()
yawpitch()
rcspitch()
gainaltvel()
raisep()